TaskController class

Constructors

TaskController({required Slide slide, required List<File> assets})

Properties

hashCode → int
The hash code for this object.
no setterinherited
neededAssets ↔ List<File>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slide → Slide
final

Methods

copyWith({Slide? slide, List<File>? assets}) → TaskController
markNeeded(File asset) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited