SlideAsset class final

Mixed-in types
Annotations
  • @MappableClass.new(includeCustomMappers: [FileMapper(), SizeMapper()])

Constructors

SlideAsset({required File file, required Size dimensions})

Properties

copyWith → SlideAssetCopyWith<SlideAsset, SlideAsset, SlideAsset>
no setterinherited
dimensions → Size
final
extension → String
no setter
file → File
final
hashCode → int
The hash code for this object.
no setterinherited
isLandscape → bool
no setter
isPortrait → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

cached(String uri) → File
mermaid(String mermaidSyntax) → File
thumbnail(Slide slide) → File

Constants

fromJson → const SlideAsset Function(String json)
fromMap → const SlideAsset Function(Map<String, dynamic> map)