MdCode class

Inheritance

Constructors

MdCode({required TextStyle? codeSpan, required EdgeInsets? codeblockPadding, required BoxDecoration? codeblockDecoration, required Color? copyIconColor, required TextStyle? codeBlock})
const

Properties

animated → AnimatedData?
finalinherited
codeBlock → TextStyle?
final
codeblockDecoration → BoxDecoration?
final
codeblockPadding → EdgeInsets?
final
codeSpan → TextStyle?
final
copyIconColor → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
isAnimated → bool
no setterinherited
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool
no setterinherited
type → Type
no setterinherited

Methods

copyWith({TextStyle? codeSpan, EdgeInsets? codeblockPadding, BoxDecoration? codeblockDecoration, Color? copyIconColor, TextStyle? codeBlock}) → MdCode
Creates a copy of this spec with the given fields replaced by the non-null parameter values.
override
getDiff(Comparable other) → Map<String, String>
inherited
lerp(covariant MdCode? other, double t) → MdCode
Linearly interpolate with another Spec object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited